@@ -74,9 +74,6 @@ VIEWER_ROLE = "roles/viewer"
 _ASSIGNMENT_DEPRECATED_MSG = """\
 Assigning to '{}' is deprecated. Use the `policy.bindings` property to modify bindings instead."""
 
-_FACTORY_DEPRECATED_MSG = """\
-Factory method {0} is deprecated. Replace with '{0}'."""
-
 _DICT_ACCESS_MSG = """\
 Dict access is not supported on policies with version > 1 or with conditional bindings."""
 
@@ -125,18 +122,22 @@ class Policy(collections_abc.MutableMapping):
 
     def __iter__(self):
         self.__check_version__()
-        return (binding["role"] for binding in self._bindings)
+        # Exclude bindings with no members
+        return (binding["role"] for binding in self._bindings if binding["members"])
 
     def __len__(self):
         self.__check_version__()
-        return len(self._bindings)
+        # Exclude bindings with no members
+        return len(list(self.__iter__()))
 
     def __getitem__(self, key):
         self.__check_version__()
         for b in self._bindings:
             if b["role"] == key:
                 return b["members"]
-        # binding does not yet exist, create one
+        # If the binding does not yet exist, create one
+        # NOTE: This will create bindings with no members
+        # which are ignored by __iter__ and __len__
         new_binding = {"role": key, "members": set()}
         self._bindings.append(new_binding)
         return new_binding["members"]
@@ -319,12 +320,7 @@ class Policy(collections_abc.MutableMapping):
 
         Returns:
             str: A member string corresponding to the given user.
-
-        DEPRECATED:  set the role `user:{email}` in the binding instead.
         """
-        warnings.warn(
-            _FACTORY_DEPRECATED_MSG.format("user:{email}"), DeprecationWarning,
-        )
         return "user:%s" % (email,)
 
     @staticmethod
@@ -337,12 +333,7 @@ class Policy(collections_abc.MutableMapping):
         Returns:
             str: A member string corresponding to the given service account.
 
-        DEPRECATED:  set the role `serviceAccount:{email}` in the binding instead.
         """
-        warnings.warn(
-            _FACTORY_DEPRECATED_MSG.format("serviceAccount:{email}"),
-            DeprecationWarning,
-        )
         return "serviceAccount:%s" % (email,)
 
     @staticmethod
@@ -354,12 +345,7 @@ class Policy(collections_abc.MutableMapping):
 
         Returns:
             str: A member string corresponding to the given group.
-
-        DEPRECATED:  set the role `group:{email}` in the binding instead.
         """
-        warnings.warn(
-            _FACTORY_DEPRECATED_MSG.format("group:{email}"), DeprecationWarning,
-        )
         return "group:%s" % (email,)
 
     @staticmethod
@@ -371,12 +357,7 @@ class Policy(collections_abc.MutableMapping):
 
         Returns:
             str: A member string corresponding to the given domain.
-
-        DEPRECATED:  set the role `domain:{email}` in the binding instead.
         """
-        warnings.warn(
-            _FACTORY_DEPRECATED_MSG.format("domain:{email}"), DeprecationWarning,
-        )
         return "domain:%s" % (domain,)
 
     @staticmethod
@@ -385,12 +366,7 @@ class Policy(collections_abc.MutableMapping):
 
         Returns:
             str: A member string representing all users.
-
-        DEPRECATED:  set the role `allUsers` in the binding instead.
         """
-        warnings.warn(
-            _FACTORY_DEPRECATED_MSG.format("allUsers"), DeprecationWarning,
-        )
         return "allUsers"
 
     @staticmethod
@@ -399,12 +375,7 @@ class Policy(collections_abc.MutableMapping):
 
         Returns:
             str: A member string representing all authenticated users.
-
-        DEPRECATED:  set the role `allAuthenticatedUsers` in the binding instead.
         """
-        warnings.warn(
-            _FACTORY_DEPRECATED_MSG.format("allAuthenticatedUsers"), DeprecationWarning,
-        )
         return "allAuthenticatedUsers"
 
     @classmethod
@@ -446,10 +417,7 @@ class Policy(collections_abc.MutableMapping):
             for binding in self._bindings:
                 members = binding.get("members")
                 if members:
-                    new_binding = {
-                        "role": binding["role"],
-                        "members": sorted(members)
-                    }
+                    new_binding = {"role": binding["role"], "members": sorted(members)}
                     condition = binding.get("condition")
                     if condition:
                         new_binding["condition"] = condition
