@@ -246,7 +246,7 @@ def test_create_channel_implicit(grpc_secure_channel, default, composite_creds_c
 @mock.patch(
     "google.auth.transport.requests.Request",
     autospec=True,
-    return_value=mock.sentinel.Request
+    return_value=mock.sentinel.Request,
 )
 @mock.patch("grpc.composite_channel_credentials")
 @mock.patch(
@@ -255,7 +255,9 @@ def test_create_channel_implicit(grpc_secure_channel, default, composite_creds_c
     return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
 @mock.patch("grpc.secure_channel")
-def test_create_channel_implicit_with_default_host(grpc_secure_channel, default, composite_creds_call, request, auth_metadata_plugin):
+def test_create_channel_implicit_with_default_host(
+    grpc_secure_channel, default, composite_creds_call, request, auth_metadata_plugin
+):
     target = "example.com:443"
     default_host = "example.com"
     composite_creds = composite_creds_call.return_value
@@ -265,7 +267,9 @@ def test_create_channel_implicit_with_default_host(grpc_secure_channel, default,
     assert channel is grpc_secure_channel.return_value
 
     default.assert_called_once_with(scopes=None, default_scopes=None)
-    auth_metadata_plugin.assert_called_once_with(mock.sentinel.credentials, mock.sentinel.Request, default_host=default_host)
+    auth_metadata_plugin.assert_called_once_with(
+        mock.sentinel.credentials, mock.sentinel.Request, default_host=default_host
+    )
 
     if grpc_helpers.HAS_GRPC_GCP:
         grpc_secure_channel.assert_called_once_with(target, composite_creds, None)
@@ -356,7 +360,7 @@ def test_create_channel_explicit_with_duplicate_credentials():
         grpc_helpers.create_channel(
             target,
             credentials_file="credentials.json",
-            credentials=mock.sentinel.credentials
+            credentials=mock.sentinel.credentials,
         )
 
 
@@ -369,7 +373,9 @@ def test_create_channel_explicit(grpc_secure_channel, auth_creds, composite_cred
 
     channel = grpc_helpers.create_channel(target, credentials=mock.sentinel.credentials)
 
-    auth_creds.assert_called_once_with(mock.sentinel.credentials, scopes=None, default_scopes=None)
+    auth_creds.assert_called_once_with(
+        mock.sentinel.credentials, scopes=None, default_scopes=None
+    )
 
     assert channel is grpc_secure_channel.return_value
     if grpc_helpers.HAS_GRPC_GCP:
@@ -403,7 +409,9 @@ def test_create_channel_explicit_scoped(grpc_secure_channel, composite_creds_cal
 
 @mock.patch("grpc.composite_channel_credentials")
 @mock.patch("grpc.secure_channel")
-def test_create_channel_explicit_default_scopes(grpc_secure_channel, composite_creds_call):
+def test_create_channel_explicit_default_scopes(
+    grpc_secure_channel, composite_creds_call
+):
     target = "example.com:443"
     default_scopes = ["3", "4"]
     composite_creds = composite_creds_call.return_value
@@ -415,7 +423,9 @@ def test_create_channel_explicit_default_scopes(grpc_secure_channel, composite_c
         target, credentials=credentials, default_scopes=default_scopes
     )
 
-    credentials.with_scopes.assert_called_once_with(scopes=None, default_scopes=default_scopes)
+    credentials.with_scopes.assert_called_once_with(
+        scopes=None, default_scopes=default_scopes
+    )
 
     assert channel is grpc_secure_channel.return_value
     if grpc_helpers.HAS_GRPC_GCP:
@@ -426,16 +436,18 @@ def test_create_channel_explicit_default_scopes(grpc_secure_channel, composite_c
 
 @mock.patch("grpc.composite_channel_credentials")
 @mock.patch("grpc.secure_channel")
-def test_create_channel_explicit_with_quota_project(grpc_secure_channel, composite_creds_call):
+def test_create_channel_explicit_with_quota_project(
+    grpc_secure_channel, composite_creds_call
+):
     target = "example.com:443"
     composite_creds = composite_creds_call.return_value
 
-    credentials = mock.create_autospec(google.auth.credentials.CredentialsWithQuotaProject, instance=True)
+    credentials = mock.create_autospec(
+        google.auth.credentials.CredentialsWithQuotaProject, instance=True
+    )
 
     channel = grpc_helpers.create_channel(
-        target,
-        credentials=credentials,
-        quota_project_id="project-foo"
+        target, credentials=credentials, quota_project_id="project-foo"
     )
 
     credentials.with_quota_project.assert_called_once_with("project-foo")
@@ -452,19 +464,21 @@ def test_create_channel_explicit_with_quota_project(grpc_secure_channel, composi
 @mock.patch(
     "google.auth.load_credentials_from_file",
     autospec=True,
-    return_value=(mock.sentinel.credentials, mock.sentinel.project)
+    return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
-def test_create_channel_with_credentials_file(load_credentials_from_file, grpc_secure_channel, composite_creds_call):
+def test_create_channel_with_credentials_file(
+    load_credentials_from_file, grpc_secure_channel, composite_creds_call
+):
     target = "example.com:443"
 
     credentials_file = "/path/to/credentials/file.json"
     composite_creds = composite_creds_call.return_value
 
-    channel = grpc_helpers.create_channel(
-        target, credentials_file=credentials_file
-    )
+    channel = grpc_helpers.create_channel(target, credentials_file=credentials_file)
 
-    google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=None, default_scopes=None)
+    google.auth.load_credentials_from_file.assert_called_once_with(
+        credentials_file, scopes=None, default_scopes=None
+    )
 
     assert channel is grpc_secure_channel.return_value
     if grpc_helpers.HAS_GRPC_GCP:
@@ -478,9 +492,11 @@ def test_create_channel_with_credentials_file(load_credentials_from_file, grpc_s
 @mock.patch(
     "google.auth.load_credentials_from_file",
     autospec=True,
-    return_value=(mock.sentinel.credentials, mock.sentinel.project)
+    return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
-def test_create_channel_with_credentials_file_and_scopes(load_credentials_from_file, grpc_secure_channel, composite_creds_call):
+def test_create_channel_with_credentials_file_and_scopes(
+    load_credentials_from_file, grpc_secure_channel, composite_creds_call
+):
     target = "example.com:443"
     scopes = ["1", "2"]
 
@@ -491,7 +507,9 @@ def test_create_channel_with_credentials_file_and_scopes(load_credentials_from_f
         target, credentials_file=credentials_file, scopes=scopes
     )
 
-    google.auth.load_credentials_from_file.assert_called_once_with(credentials_file, scopes=scopes, default_scopes=None)
+    google.auth.load_credentials_from_file.assert_called_once_with(
+        credentials_file, scopes=scopes, default_scopes=None
+    )
 
     assert channel is grpc_secure_channel.return_value
     if grpc_helpers.HAS_GRPC_GCP:
@@ -505,9 +523,11 @@ def test_create_channel_with_credentials_file_and_scopes(load_credentials_from_f
 @mock.patch(
     "google.auth.load_credentials_from_file",
     autospec=True,
-    return_value=(mock.sentinel.credentials, mock.sentinel.project)
+    return_value=(mock.sentinel.credentials, mock.sentinel.project),
 )
-def test_create_channel_with_credentials_file_and_default_scopes(load_credentials_from_file, grpc_secure_channel, composite_creds_call):
+def test_create_channel_with_credentials_file_and_default_scopes(
+    load_credentials_from_file, grpc_secure_channel, composite_creds_call
+):
     target = "example.com:443"
     default_scopes = ["3", "4"]
 
@@ -518,7 +538,9 @@ def test_create_channel_with_credentials_file_and_default_scopes(load_credential
         target, credentials_file=credentials_file, default_scopes=default_scopes
     )
 
-    load_credentials_from_file.assert_called_once_with(credentials_file, scopes=None, default_scopes=default_scopes)
+    load_credentials_from_file.assert_called_once_with(
+        credentials_file, scopes=None, default_scopes=default_scopes
+    )
 
     assert channel is grpc_secure_channel.return_value
     if grpc_helpers.HAS_GRPC_GCP:
